@@ -1,4 +1,6 @@
 from pytorch_pfn_extras import config  # NOQA
+from pytorch_pfn_extras import dataset  # NOQA
+from pytorch_pfn_extras import dataloaders  # NOQA
 from pytorch_pfn_extras import nn  # NOQA
 from pytorch_pfn_extras import reporting  # NOQA
 from pytorch_pfn_extras import training  # NOQA
